@@ -893,7 +893,13 @@ ReplicaAutoScalingDescriptionTypeDef = TypedDict(
         "ReplicaProvisionedReadCapacityAutoScalingSettings": "AutoScalingSettingsDescriptionTypeDef",
         "ReplicaProvisionedWriteCapacityAutoScalingSettings": "AutoScalingSettingsDescriptionTypeDef",
         "ReplicaStatus": Literal[
-            "CREATING", "CREATION_FAILED", "UPDATING", "DELETING", "ACTIVE", "REGION_DISABLED"
+            "CREATING",
+            "CREATION_FAILED",
+            "UPDATING",
+            "DELETING",
+            "ACTIVE",
+            "REGION_DISABLED",
+            "INACCESSIBLE_ENCRYPTION_CREDENTIALS",
         ],
     },
     total=False,
@@ -904,7 +910,13 @@ ReplicaDescriptionTypeDef = TypedDict(
     {
         "RegionName": str,
         "ReplicaStatus": Literal[
-            "CREATING", "CREATION_FAILED", "UPDATING", "DELETING", "ACTIVE", "REGION_DISABLED"
+            "CREATING",
+            "CREATION_FAILED",
+            "UPDATING",
+            "DELETING",
+            "ACTIVE",
+            "REGION_DISABLED",
+            "INACCESSIBLE_ENCRYPTION_CREDENTIALS",
         ],
         "ReplicaStatusDescription": str,
         "ReplicaStatusPercentProgress": str,
@@ -1008,7 +1020,13 @@ _OptionalReplicaSettingsDescriptionTypeDef = TypedDict(
     "_OptionalReplicaSettingsDescriptionTypeDef",
     {
         "ReplicaStatus": Literal[
-            "CREATING", "CREATION_FAILED", "UPDATING", "DELETING", "ACTIVE", "REGION_DISABLED"
+            "CREATING",
+            "CREATION_FAILED",
+            "UPDATING",
+            "DELETING",
+            "ACTIVE",
+            "REGION_DISABLED",
+            "INACCESSIBLE_ENCRYPTION_CREDENTIALS",
         ],
         "ReplicaBillingModeSummary": "BillingModeSummaryTypeDef",
         "ReplicaProvisionedReadCapacityUnits": int,
